``pulp_rpm`` Plugin
===================

.. image:: https://travis-ci.org/pulp/pulp_rpm.svg?branch=master
    :target: https://travis-ci.org/pulp/pulp_rpm

This is the ``pulp_rpm`` Plugin for `Pulp Project
3.0+ <https://pypi.python.org/pypi/pulpcore/>`__. This plugin provides support for RPM family
content types, similar to the ``pulp_rpm`` plugin for Pulp 2.

For more information, please see the `documentation
<http://pulp-rpm.readthedocs.io/en/latest/>`_ or the `Pulp project page
<https://pulpproject.org>`_.
